## ----setup, include=FALSE-----------------------------------------------------
library(knitr)

opts_chunk$set(cache = TRUE)
opts_chunk$set(echo = TRUE)
opts_chunk$set(eval = TRUE)
opts_chunk$set(fig.height = 6)
opts_chunk$set(fig.width = 6)
opts_chunk$set(message = FALSE)
opts_chunk$set(results = "hold")
opts_chunk$set(warning = FALSE)

